=============
Release notes
=============

Release notes for each version of Oscar published to PyPI.

1.2 release branch

.. toctree::
    :maxdepth: 1

    v1.2
    v1.2.1
    v1.2.2

1.1 release branch

.. toctree::
    :maxdepth: 1

    v1.1
    v1.1.1

1.0 release branch

.. toctree::
    :maxdepth: 1

    v1.0
    v1.0.1
    v1.0.2

0.7 release branch

.. toctree::
    :maxdepth: 1

    v0.7
    v0.7.1
    v0.7.2
    v0.7.3

0.6 release branch

.. toctree::
    :maxdepth: 1

    v0.6
    v0.6.1
    v0.6.2
    v0.6.3
    v0.6.4
    v0.6.5

0.5 release branch

.. toctree::
    :maxdepth: 1

    v0.5
    v0.5.1
    v0.5.2
    v0.5.3
